@@ -2,12 +2,12 @@ use 5.014;
 use strict;
 use warnings;
 
-use Kavorka::Signature::Parameter ();
+use Kavorka::Parameter ();
 
 package Kavorka::Sub::Method;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.016';
+our $VERSION   = '0.017';
 
 use Moo;
 with 'Kavorka::Sub';
@@ -25,7 +25,7 @@ sub default_invocant
 {
 	my $self = shift;
 	return (
-		'Kavorka::Signature::Parameter'->new(
+		'Kavorka::Parameter'->new(
 			as_string => '$self:',
 			name      => '$self',
 			traits    => { invocant => 1 },
